summaryrefslogtreecommitdiff
path: root/noncore/settings
Side-by-side diff
Diffstat (limited to 'noncore/settings') (more/less context) (show whitespace changes)
-rw-r--r--noncore/settings/networksettings/wlan/wlan.pro2
-rw-r--r--noncore/settings/networksettings/wlan/wlanimp2.cpp6
2 files changed, 5 insertions, 3 deletions
diff --git a/noncore/settings/networksettings/wlan/wlan.pro b/noncore/settings/networksettings/wlan/wlan.pro
index e975dde..eb9dd4f 100644
--- a/noncore/settings/networksettings/wlan/wlan.pro
+++ b/noncore/settings/networksettings/wlan/wlan.pro
@@ -10,3 +10,3 @@ INTERFACES = wlan.ui info.ui
TARGET = wlan
-VERSION = 1.0.0
+VERSION = 1.0.1
diff --git a/noncore/settings/networksettings/wlan/wlanimp2.cpp b/noncore/settings/networksettings/wlan/wlanimp2.cpp
index 5cb78cf..11dfe74 100644
--- a/noncore/settings/networksettings/wlan/wlanimp2.cpp
+++ b/noncore/settings/networksettings/wlan/wlanimp2.cpp
@@ -372,3 +372,4 @@ void WLANImp::rescanNeighbourhood()
- // display splash screen
+ // disable button and display splash screen
+ rescanButton->setEnabled( false );
QFrame* splash = new QFrame( this, "splash", false, WStyle_StaysOnTop | WStyle_DialogBorder | WStyle_Customize );
@@ -418,5 +419,6 @@ void WLANImp::rescanNeighbourhood()
+ // hide splash screen and reenable button
splash->hide();
delete splash;
-
+ rescanButton->setEnabled( true );
}